Callstack

Struct Callstack 

pub struct Callstack<const NF: usize> { /* private fields */ }
An optimized Callstack struct that represents a single stack trace. No symbols are explicitly held here - the major savings is that we use an external dictionary to store symbols, because the same IPs are used over and over in many stack traces.

To reduce allocations, we only keep MAX_NUM_FRAMES frames.

Implementations

Source

impl<const NF: usize> Callstack<NF>

pub fn from_backtrace_unresolved(bt: &Backtrace) -> Self

Creates a Callback from a backtrace::Backtrace, preferably unresolved for speed

pub fn compute_hash(&self) -> u64