pub struct DecoratedCallstack<'cb, 's, const NF: usize> { /* private fields */ }Expand description
DecoratedCallstack enables detailed stack trace printouts. Each callstack consists of multiple frames, parent frame calls the child frame so on. Each frame may expand to include multiple symbols, especially due to inlining.
filename_info- if True, prints out source filename infofilter_poll- if True, skips symbols in the frame which have::poll::in themexpand_frame- if False, does not print out inlined symbols at allwrite_header- if True, adds “Callback <hash = 0x..>” header as the first line