Module utils

Module utils 

Structs

ProfilerRunner
A background thread that dumps out stats, flamegraphs, and does other periodic cleanup.
ProfilerRunnerBuilder
Builder for ProfilerRunner.

Enums

ProfilerRunnerBuilderError
Error type for ProfilerRunnerBuilder

Constants

DEFAULT_CHECK_INTERVAL_SECS
Default seconds between memory checks.
DEFAULT_PCT_CHANGE_TRIGGER
Default percent change in memory that triggers a report.
DEFAULT_REPORTING_PATH
Directory that YingProfiler::start_profiling writes reports and flamegraphs to.

Functions

gen_flamegraph
Function to produce a FlameGraph file to a specific path. Specify whether to measure retained or allocated bytes, and the path to write flamegraph file to (should probably end in .svg)