DecoratedCallstack

Struct DecoratedCallstack 

pub struct DecoratedCallstack<'cb, 's, const NF: usize> { /* private fields */ }
DecoratedCallstack enables detailed stack trace printouts. Each callstack consists of multiple frames, parent frame calls the child frame so on. Each frame may expand to include multiple symbols, especially due to inlining.

  • filename_info - if True, prints out source filename info
  • filter_poll - if True, skips symbols in the frame which have ::poll:: in them
  • expand_frame - if False, does not print out inlined symbols at all
  • write_header - if True, adds “Callback <hash = 0x..>” header as the first line