Structs
- Profiler
Runner - A background thread that dumps out stats, flamegraphs, and does other periodic cleanup.
- Profiler
Runner Builder - Builder for
ProfilerRunner.
Enums
- Profiler
Runner Builder Error - Error type for ProfilerRunnerBuilder
Constants
- DEFAULT_
CHECK_ INTERVAL_ SECS - Default seconds between memory checks.
- DEFAULT_
PCT_ CHANGE_ TRIGGER - Default percent change in memory that triggers a report.
- DEFAULT_
REPORTING_ PATH - Directory that
YingProfiler::start_profilingwrites reports and flamegraphs to.
Functions
- gen_
flamegraph - Function to produce a FlameGraph file to a specific path. Specify whether to measure retained or allocated bytes, and the path to write flamegraph file to (should probably end in .svg)